summaryrefslogtreecommitdiff
path: root/src/memberinfo.h
diff options
context:
space:
mode:
authorMartijn Otto <martijn.otto@copernica.com>2014-02-14 16:30:23 +0100
committerMartijn Otto <martijn.otto@copernica.com>2014-02-14 16:30:23 +0100
commit06aa5fd5afaba69544b93654fb0a4f9c2651306e (patch)
tree99cd2ee120786a84531b450f9ef64e2319ef5192 /src/memberinfo.h
parent5c23fee5ce58ae66a70f3bd19a1dc2dff7220f13 (diff)
Merged pull request #14
Diffstat (limited to 'src/memberinfo.h')
-rw-r--r--src/memberinfo.h13
1 files changed, 11 insertions, 2 deletions
diff --git a/src/memberinfo.h b/src/memberinfo.h
index 040f0de..1c4b59d 100644
--- a/src/memberinfo.h
+++ b/src/memberinfo.h
@@ -68,14 +68,23 @@ public:
* @param flags Additional flags
*/
virtual void declare(struct _zend_class_entry *entry, const char *name, int size, int flags) {};
+
+ /**
+ * Virtual method to declare the constant property
+ * @param entry Class entry
+ * @param name Name of the member
+ * @param size Size of the name
+ * @param flags Additional flags
+ */
+ virtual void declareConst(struct _zend_class_entry *entry, const char *name, int size) {};
/**
* Fill a function entry object
* @param entry Function entry
* @param classname Name of the class
* @param pub Is this a public method?
*/
- virtual void fill(struct _zend_function_entry *entry, const char *classname, bool pub) {};
+ virtual void fill(struct _zend_function_entry *entry, const char *classname, int flags) {};
};
@@ -68,14 +68,23 @@ public:
* @param entry Function entry
* @param classname Name of the class
- * @param pub Is this a public method?
+ * @param flags Is this a public method?
*/